@@ -25,11 +25,19 @@ def env():
     valid_icon = "\U00002714"
     failed_icon = "\U0000274C"
 
-    click.echo(f"Current Environment:")
+    projectConfig = get_config()
+
+    click.echo(f"Project Info:\n--------------------------------")
+    try:
+        click.echo(f'Vi: {projectConfig["default"]["vi"]}')
+        click.echo(f'Core: {projectConfig["default"]["core"]}')
+    except:
+        echo_error("Error while collecting viur info")
+    click.echo(f"\nCurrent Environment:\n--------------------------------")
 
     # viur-cli
     if shutil.which("viur"):
-        app_server_version = subprocess.check_output(['viur', '-v']).decode("utf-8")
+        app_server_version = subprocess.check_output(['viur', '--version']).decode("utf-8")
         click.echo(f"{valid_icon} {app_server_version}")
     else:
         click.echo(f"{failed_icon} ViUR-CLI")
@@ -41,6 +49,13 @@ def env():
     else:
         click.echo(f"{failed_icon} app_server")
 
+    # git
+    if shutil.which("git"):
+        git_version = subprocess.check_output(['git', '--version']).decode("utf-8")
+        click.echo(f"{valid_icon} {git_version}")
+    else:
+        click.echo(f"{failed_icon}")
+
     # python3
     if shutil.which("python3"):
         npm_version = subprocess.check_output(['python3', '-V']).decode("utf-8")
